Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(195)

Unified Diff: media/base/media_observer.h

Issue 2767823002: Media Remoting: Add interstitial elements to media element shadow dom. (Closed)
Patch Set: Rebased. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/child/blink_platform_impl.cc ('k') | media/blink/webmediaplayer_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/media_observer.h
diff --git a/media/base/media_observer.h b/media/base/media_observer.h
index f5b1fb6906333ccf234031a23700a5629019f0d7..0181b1d00be6b41f47d8f6ccd44c55cda4ad5685 100644
--- a/media/base/media_observer.h
+++ b/media/base/media_observer.h
@@ -16,9 +16,10 @@ class MEDIA_EXPORT MediaObserverClient {
virtual ~MediaObserverClient() {}
// Requests to restart the media pipeline and create a new renderer as soon as
- // possible. |disable_pipeline_auto_suspend| indicates whether to disable
- // any optimizations that might suspend the media pipeline.
- virtual void SwitchRenderer(bool disable_pipeline_auto_suspend) = 0;
+ // possible. |is_rendered_remotely| indicates whether the media is rendered
+ // remotely. When it is true, all the optimizations that might suspend the
+ // media pipeline should be disabled.
+ virtual void SwitchRenderer(bool is_rendered_remotely) = 0;
// Requests to activate monitoring changes on viewport intersection.
virtual void ActivateViewportIntersectionMonitoring(bool activate) = 0;
« no previous file with comments | « content/child/blink_platform_impl.cc ('k') | media/blink/webmediaplayer_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698